@@ -4,7 +4,9 @@ import os
 import sys
 import unittest
 
-from .common import *
+import av
+
+from .common import TestCase
 
 # On Windows, Python 3.0 - 3.5 have issues handling unicode filenames.
 # Starting with Python 3.6 the situation is saner thanks to PEP 529:
@@ -22,4 +24,4 @@ class TestContainers(TestCase):
     @unittest.skipIf(broken_unicode, 'Unicode filename handling is broken')
     def test_unicode_filename(self):
 
-        container = av.open(self.sandboxed(u'¢∞§¶•ªº.mov'), 'w')
+        av.open(self.sandboxed(u'¢∞§¶•ªº.mov'), 'w')
