@@ -1,16 +1,24 @@
 from __future__ import division
 
-import math
+import av
+
+from .common import MethodLogger, TestCase, fate_suite
+from .test_encode import assert_rgb_rotate, write_rgb_rotate
+
 try:
     from cStringIO import StringIO
 except ImportError:
     from io import BytesIO as StringIO
 
-from .common import *
-from .test_encode import write_rgb_rotate, assert_rgb_rotate
-from av.video.stream import VideoStream
 
+class NonSeekableBuffer:
+    def __init__(self, data):
+        self.data = data
 
+    def read(self, n):
+        data = self.data[0:n]
+        self.data = self.data[n:]
+        return data
 
 
 class TestPythonIO(TestCase):
@@ -32,6 +40,24 @@ class TestPythonIO(TestCase):
             reads = wrapped._filter('read')
             self.assertTrue(reads)
 
+    def test_reading_no_seek(self):
+        with open(fate_suite('mpeg2/mpeg2_field_encoding.ts'), 'rb') as fh:
+            data = fh.read()
+
+        buf = NonSeekableBuffer(data)
+        wrapped = MethodLogger(buf)
+
+        container = av.open(wrapped)
+
+        self.assertEqual(container.format.name, 'mpegts')
+        self.assertEqual(container.format.long_name, "MPEG-TS (MPEG-2 Transport Stream)")
+        self.assertEqual(len(container.streams), 1)
+        self.assertEqual(container.metadata, {})
+
+        # Make sure it did actually call "read".
+        reads = wrapped._filter('read')
+        self.assertTrue(reads)
+
     def test_basic_errors(self):
         self.assertRaises(Exception, av.open, None)
         self.assertRaises(Exception, av.open, None, 'w')
